# Contributing

Contributions are welcome, and greatly appreciated! Every little bit helps, and credit will always be given.

If you need support, want to report/fix a bug, ask for/implement features, you can check the
[Issues page](https://github.com/AI-Planning/pddl/issues)
or [submit a Pull request](https://github.com/AI-Planning/pddl/pulls).

For other kinds of feedback, you can contact one of the [authors](./authors.md) by email.
